@@ -1,7 +1,14 @@
 from pathlib import Path
 from random import choice
 from typing import Optional
-from cosa.transform import k_representative_pallette, elastic_transform, jpeg
+from cosa.transform import (
+    k_representative_pallette,
+    elastic_transform,
+    jpeg,
+    voronoi,
+    dither,
+    intarsia,
+)
 from PIL import Image
 import numpy as np
 
@@ -9,6 +16,9 @@ FUNCTIONS = {
     "k_rep": k_representative_pallette,
     "elastic": elastic_transform,
     "jpeg": jpeg,
+    "voronoi": voronoi,
+    "dither": dither,
+    "intarsia": intarsia,
 }
 
 
